#
# --- grubmenu ---
#
# constants.py
#
# various symbols used by grubmenu
# the constant which grubmenu uses is described by this file.
#
# Copyright (c) 2003 by kaepapa <kaepapa@kaepapa.dip.jp>

# grubmenu version
VERSION = "grubmenu 0.2.4"

# boot directory
BOOT = "/boot"

# path to configuration file
CONF_FILE = "/etc/grubmenu.conf"

# the candidate of a GRUB directory
GRUB_DIRS = ['/boot/grub/','/boot/boot/grub/']

# path to fstab file
FSTAB_FILE = "/etc/fstab"

# version files list
VER_FILES = [['/etc/debian_version','DebianGNU/Linux'],
             ['/etc/vine-release','Vine Linux'],
             ['/etc/redhat-release','Redhat Linux'],
             ['/etc/gentoo-release','Gentoo Linux']]

# the character color on the grub menu
STR_COLOR = ['black','blue','green','cyan','red','magenta','brown','light-gray','dark-gray',\
         'light-blue','light-green','light-cyan','light-red','light-magenta','yellow','white']

# the background color on the grub menu
BG_COLOR = ['black','blue','green','cyan','red','magenta','brown','light-gray']

